#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2
#
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2023-12-28
# File  : fritzbox_smarthome.py (metrics)

from cmk.gui.i18n import _
from cmk.gui.plugins.metrics.utils import (
    metric_info,
    graph_info,
    check_metrics,
    perfometer_info,
    unit_info,
)
from cmk.utils.render import fmt_number_with_precision

unit_info["CURRENCY"] = {
    "title": _("Currency"),
    "symbol": "¤",  # https://en.wikipedia.org/wiki/Currency_sign_(typography)
    # "render": lambda v: "%s ¤" % v,
    # "render": lambda v: f"{v:.4f} ¤",
    # "js_render": "v => v.toFixed(2) + ' ¤'",
    "render": lambda v: fmt_number_with_precision(v, precision=4, drop_zeroes=True, unit='¤'),
    "js_render": "v => cmk.number_format.fmt_number_with_precision(v, cmk.number_format.SIUnitPrefixes, 4, true, '¤')",
}
check_metrics["check_mk-fritzbox_smarthome_thermostat_single"] = {
    "temp_current": {"auto_graph": False},
    "temp_target": {"auto_graph": False},
    "temp_economic": {"auto_graph": False},
    "temp_comfort": {"auto_graph": False},
}
check_metrics["check_mk-fritzbox_smarthome_thermostat_multiple"] = {
    "temp_current": {"auto_graph": False},
    "temp_target": {"auto_graph": False},
    "temp_economic": {"auto_graph": False},
    "temp_comfort": {"auto_graph": False},
}

metric_info["battery"] = {
    "title": _("Battery"),
    "color": "14/b",
    "unit": "%",
}
metric_info["cost_last_reading"] = {
    "title": _("Cost last"),
    "color": "11/b",
    "unit": "CURRENCY",
}
metric_info["cost_per_hour"] = {
    "title": _("Cost this hour"),
    "color": "13/a",
    "unit": "CURRENCY",
}
metric_info["cost_per_day"] = {
    "title": _("Cost this day"),
    "color": "23/a",
    "unit": "CURRENCY",
}
metric_info["cost_per_month"] = {
    "title": _("Cost this month"),
    "color": "33/a",
    "unit": "CURRENCY",
}
metric_info["cost_per_year"] = {
    "title": _("Cost this year"),
    "color": "43/a",
    "unit": "CURRENCY",
}
metric_info["energy_total"] = {
    "title": _("Energy total"),
    "color": "31/b",
    "unit": "wh",
}
metric_info["energy_current"] = {
    "title": _("Energy since last"),
    "color": "16/b",
    "unit": "wh",
}
metric_info["energy_timespan"] = {
    "title": _("Time between readings"),
    "color": "36/b",
    "unit": "s",
}

metric_info["temp_current"] = {
    "title": _("Temperature current"),
    "color": "26/a",
    "unit": "c",
}
metric_info["temp_target"] = {
    "title": _("Temperature target"),
    "color": "21/a",
    "unit": "c",
}
metric_info["temp_economic"] = {
    "title": _("Temperature cool-down"),
    "color": "31/a",
    "unit": "c",
}
metric_info["temp_comfort"] = {
    "title": _("Temperature comfort"),
    "color": "11/a",
    "unit": "c",
}
metric_info["temp_deviation"] = {
    "title": _("Temperature deviation"),
    "color": "35/a",
    "unit": "c",
}
graph_info["fritzbox_smart_home_energy_cost"] = {
    "title": "Electrical energy cost",
    "metrics": [
        ("cost_per_year", "area"),
        ("cost_per_month", "area"),
        ("cost_per_day", "area"),
        ("cost_per_hour", "area"),
    ],
    "optional_metrics": [
        "cost_per_hour",
        "cost_per_day",
        "cost_per_month",
        "cost_per_year",
    ],
}

graph_info["fritzbox_smart_home_energy_surrent"] = {
    "title": "Electrical energy consumption since last reading",
    "metrics": [
        ("energy_current", "area")
    ]
}

graph_info["fritzbox_smart_home_energy_time_span"] = {
    "title": "Electrical energy time between readings",
    "metrics": [
        ("energy_timespan", "area")
    ]
}

graph_info["fritzbox_smart_home_energy_total"] = {
    "title": "Electrical energy consumption total",
    "metrics": [
        ("energy_total", "area")
    ]
}

graph_info["fritzbox_smart_home_electrical_power"] = {
    "title": "Electrical power",
    "metrics": [
        ("power", "area")
    ]
}
graph_info["fritzbox_smart_home_humidity"] = {
    "title": "Relative humidity",
    "metrics": [
        ("humidity", "area")
    ]
}
graph_info["fritzbox_smart_home_temp_control"] = {
    "title": _("Thermostat temperature control"),
    "metrics": [
        ("temp_current", "area"),
        ("temp_target", "line"),
    ],
    "scalars": [
        ("temp_comfort", "Temperature comfort"),
        ("temp_economic", "Temperature cool-down"),
    ],
    "optional_metrics": [
        "temp_target",
    ],
}

perfometer_info.append(('stacked', [
    {
        'type': 'linear',
        'segments': ['temp_current'],
        'total': 50,
    },
    {
        'type': 'linear',
        'segments': ['temp_target'],
        'total': 50,
    }
]))

perfometer_info.append({
    "type": "logarithmic",
    "metric": "energy_current",
    "half_value": 100,
    "exponent": 3,
})

perfometer_info.append({
    "type": "linear",
    'segments': ['battery'],
    'total': 100,
})